@@ -126,3 +126,11 @@
   return(num_fun2)
 }
 
+#' re-export magrittr pipe operator
+#'
+#' @importFrom magrittr %>%
+#' @name %>%
+#' @rdname pipe
+#' @export
+NULL
+
